@@ -2,7 +2,7 @@
 #Anthony G. Persaud
 
 use strict;
-use Nmap::Parser 1.00;
+use Nmap::Parser;
 use Getopt::Long;
 use File::Spec;
 use Pod::Usage;
@@ -12,7 +12,7 @@ $G{nmap_exe} = find_exe();
 
 my $np = new Nmap::Parser;
 
-print "\nscan.pl - ( http://nmapparser.wordpress.com )\n", ( '-' x 80 ), "\n\n";
+print "\nscan.pl - ( http://anthonypersaud.com )\n", ( '-' x 80 ), "\n\n";
 
 GetOptions(
     'help|h|?' => \$G{helpme},
@@ -285,16 +285,18 @@ L<http://code.google.com/p/nmap-parser/w/list>
 
 L<Nmap::Parser>
 
-The Nmap::Parser page can be found at: L<http://nmapparser.wordpress.com> or L<http://npx.sourceforge.net>.
+The Nmap::Parser page can be found at: L<http://anthonypersaud.com/category/nmap-parser/>.
 It contains the latest developments on the module. The nmap security scanner
 homepage can be found at: L<http://www.insecure.org/nmap/>.
 
 =head1 AUTHOR
 
-Anthony G Persaud <apersaud[at]gmail.com> L<http://www.anthonypersaud.com>
+Anthony G Persaud L<http://anthonypersaud.com>
 
 =head1 COPYRIGHT
 
+Copyright (c) <2003-2009> <Anthony G. Persaud>
+
 MIT License
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -314,5 +316,4 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
-
 =cut
